IteratorMixin - Qudas 0.1.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# IteratorMixin

class qudas.pipeline.steps.IteratorMixin(loop_num: int = 1)

  パイプラインステップ内で使用するイテレータ用のMixinクラス。 このMixinクラスは次のパラメータセットを生成する next_params メソッドの実装を要求します。

  abstract next_params(X: Any, y: Any | None = None, **iter_params) → Tuple[Any, Any]

    次のパラメータセットを生成する抽象メソッド。

    Parameters:

      - X (Any) – 入力データ。

      - y (Any) – ターゲットデータ。

      - **iter_params – 追加のパラメータ。

    Returns:

      次の入力データとターゲットデータ。

    Return type:

      Tuple[Any, Any]